@@ -6,7 +6,7 @@
     | modification, are permitted provided that the conditions mentioned |
     | in the accompanying LICENSE file are met.                          |
     +--------------------------------------------------------------------+
-    | Copyright (c) 2004-2013, Michael Wallner <mike@php.net>            |
+    | Copyright (c) 2004-2014, Michael Wallner <mike@php.net>            |
     +--------------------------------------------------------------------+
 */
 
@@ -300,6 +300,14 @@ void php_http_message_update_headers(php_http_message_t *msg)
 				zval_ptr_dtor(&h);
 			}
 		}
+	} else if ((h = php_http_message_header(msg, ZEND_STRL("Content-Length"), 1))) {
+		zval *h_cpy = php_http_ztyp(IS_LONG, h);
+
+		zval_ptr_dtor(&h);
+		if (Z_LVAL_P(h_cpy)) {
+			zend_hash_del(&msg->hdrs, "Content-Length", sizeof("Content-Length"));
+		}
+		zval_ptr_dtor(&h_cpy);
 	}
 }
 
@@ -784,7 +792,7 @@ STATUS php_http_message_object_set_body(php_http_message_object_t *msg_obj, zval
 
 STATUS php_http_message_object_init_body_object(php_http_message_object_t *obj)
 {
-	TSRMLS_FETCH_FROM_CTX(obj);
+	TSRMLS_FETCH_FROM_CTX(obj->message->ts);
 
 	php_http_message_body_addref(obj->message->body);
 	return php_http_new(NULL, php_http_message_body_class_entry, (php_http_new_t) php_http_message_body_object_new_ex, NULL, obj->message->body, (void *) &obj->body TSRMLS_CC);
@@ -1808,7 +1816,9 @@ ZEND_BEGIN_ARG_INFO_EX(ai_HttpMessage_count, 0, 0, 0)
 ZEND_END_ARG_INFO();
 static PHP_METHOD(HttpMessage, count)
 {
-	if (SUCCESS == zend_parse_parameters_none()) {
+	long count_mode = -1;
+
+	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|l", &count_mode)) {
 		long i = 0;
 		php_http_message_object_t *obj = zend_object_store_get_object(getThis() TSRMLS_CC);
 
